# geodemora

[![image](https://img.shields.io/pypi/v/geodemora.svg)](https://pypi.python.org/pypi/geodemora)

[![image](https://img.shields.io/conda/vn/conda-forge/geodemora.svg)](https://anaconda.org/conda-forge/geodemora)

[![image](https://img.shields.io/conda/vn/conda-forge/geodemora.svg)](https://anaconda.org/conda-forge/geodemora)
[![image](https://pepy.tech/badge/geodemora)](https://pepy.tech/project/geodemora)
[![image](https://github.com/giswqs/geodemora/workflows/docs/badge.svg)](https://geodemora.org)
[![image](https://github.com/giswqs/geodemora/workflows/build/badge.svg)](https://github.com/giswqs/geodemora/actions?query=workflow%3Abuild)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/giswqs/geodemora.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/giswqs/geodemora/context:python)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**A python package for interactive mapping**


-   Free software: MIT license
-   Documentation: https://ramendra1990.github.io/geodemora
    

## Features

-   TODO
-   TODO2

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
